@@ -19,9 +19,6 @@
  */
 
 #include <config.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
 #include <stdlib.h>
 #include <time.h>
 
